package org.cesar.flip;

import java.io.File;

import org.eclipse.core.resources.ISaveContext;
import org.eclipse.core.resources.ISaveParticipant;
import org.eclipse.core.resources.IWorkspace;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.Path;


/**
 * A FLiP participant in the saving of the workspace.
 * 
 * @see IWorkspace#save(boolean, org.eclipse.core.runtime.IProgressMonitor)
 */
public class FlipPluginSaveParticipant implements ISaveParticipant {

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.core.resources.ISaveParticipant#doneSaving(org.eclipse.core.resources.ISaveContext)
	 */
	public void doneSaving(ISaveContext context) {
		FlipPlugin myPluginInstance = FlipPlugin.getDefault();
		int previousSaveNumber = context.getPreviousSaveNumber();
		String oldFileName = FlipMessages.flip_plugin_file_name
				+ Integer.toString(previousSaveNumber)
				+ FlipMessages.flip_plugin_file_extension;
		File f = myPluginInstance.getStateLocation().append(oldFileName)
				.toFile();
		f.delete();
	}

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.core.resources.ISaveParticipant#prepareToSave(org.eclipse.core.resources.ISaveContext)
	 */
	public void prepareToSave(ISaveContext context) throws CoreException {
	}

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.core.resources.ISaveParticipant#rollback(org.eclipse.core.resources.ISaveContext)
	 */
	public void rollback(ISaveContext context) {
	}

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.core.resources.ISaveParticipant#saving(org.eclipse.core.resources.ISaveContext)
	 */
	public void saving(ISaveContext context) throws CoreException {
		switch (context.getKind()) {
		case ISaveContext.FULL_SAVE:
			FlipPlugin myPluginInstance = FlipPlugin.getDefault();
			int saveNumber = context.getSaveNumber();
			String saveFileName = FlipMessages.flip_plugin_file_name
					+ Integer.toString(saveNumber)
					+ FlipMessages.flip_plugin_file_extension;
			File f = myPluginInstance.getStateLocation().append(saveFileName)
					.toFile();
			myPluginInstance.writeImportantState(f);
			context.map(new Path(FlipMessages.flip_plugin_path), new Path(
					saveFileName));
			context.needSaveNumber();
			break;
		case ISaveContext.PROJECT_SAVE:
			break;
		case ISaveContext.SNAPSHOT:
			break;
		}
	}
}
