package org.cesar.flip;

import java.util.List;
import java.util.Map;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IProject;

/**
 * Represents a Transaction that has an <code>IFeature</code> <br>
 * or an <code>IExpression</code> and an <code>IComponent</code>
 * 
 * @author Vilmar Nepomuceno (vilmar.nepomuceno@cesar.org.br)
 * 
 */
public class Transaction {

	/**
	 * Name of the transaction
	 */
	private String name;


	/**
	 * Associations between features and aspects
	 */
	private Map<String, String> associations;
	

	/**
	 * The file where the extracted code will reside
	 */
	private List<IFile> destinations;

	/**
	 * The transaction's project.
	 */
	private IProject project;

	/**
	 * Creates a transaction with the given name, description and destination
	 * files.
	 * 
	 * @param name
	 *            the name of the transaction
	 * @param description
	 *            the descritption of the transaction
	 * @param destinations
	 *            the destination files
	 */
	public Transaction(String name, Map<String, String> associations, List<IFile> destinations) {
		this.name = name;
		this.associations = associations;
		this.destinations = destinations;
		this.project = this.destinations.get(0).getProject();
	}

	/**
	 * Gets the name of the transaction
	 * 
	 * @return name the name of the transaction
	 */
	public String getName() {
		return this.name;
	}

	/**
	 * Returns the destination files of this extraction.
	 * 
	 * @return The destination files of the extracted code
	 */
	public List<IFile> getDestinations() {
		return this.destinations;
	}

	/**
	 * Sets the destination files of this extraction.
	 * 
	 * @param destination
	 *            files Where the extracted code will reside
	 */
	public void setDestinations(List<IFile> destinations) {
		this.destinations = destinations;
	}

	/**
	 * Gets the transaction's project
	 * 
	 * @return project the transaction's project
	 */
	public IProject getProject() {
		return this.project;
	}

	/**
	 * Gets the associations.
	 * 
	 * @return associations
	 */
	public Map<String, String> getAssociations() {
		return associations;
	}

	/**
	 * Sets the associations.
	 * 
	 * @param associations
	 */
	public void setAssociations(
			Map<String, String> associations) {
		this.associations = associations;
	}
	
}
