package org.cesar.flip.flipc;

import java.util.List;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.IProgressMonitor;

/**
 * Interface that build Tools must implement.
 * 
 * Provides all the services needed by FLiP from build Tools.
 * 
 * @author Vilmar Nepomuceno (Vilmar.Nepomuceno@cesar.org.br)
 * 
 */
public interface IBuildExecution {

	
	/**
	 * Executes the build job for the given project.
	 * 
	 * 
	 * @param project
	 * 			the selected project to be built.
	 * @param monitor
	 * 			the progress monitor
	 * @return Log location
	 * @throws CoreException
	 */
	public String runBuild(IProject project, IProgressMonitor monitor) throws CoreException;
	
	/**
	 * Transforms all variant models in the given project.
	 * 
	 * @param project
	 *            the project containing the models that will be transformed
	 * @param modelDescriptorsPaths
	 *            the path to the model descriptors
	 * @param outputPath
	 *            the output path of the transformations
	 * @param monitor
	 *            the progress monitor
	 * @throws CoreException 
	 */
	public void transformAllModels(IProject project,
			List<String> modelDescriptorsPaths, IPath outputPath,
			IProgressMonitor monitor) throws CoreException;
}
