package org.cesar.flip.flipex;

import java.util.LinkedList;

import org.cesar.flip.flipex.util.JavaUtil;
import org.eclipse.core.resources.IFile;
import org.eclipse.jdt.core.dom.ASTNode;
import org.eclipse.jdt.core.dom.CompilationUnit;

/**
 * Represents a simple (non-preprocessed) Java selection for refactoring.
 * 
 * @author Fernando Calheiros (fernando.calheiros@cesar.org.br)
 * 
 */
public class JavaRefactoringInfo extends RefactoringInfo {
	/**
	 * AST of the java source
	 */
	protected CompilationUnit javaCompilationUnit;

	/**
	 * The selected nodes.
	 */
	protected LinkedList<ASTNode> selectedNodes;

	/**
	 * Creates a description of the selected java code for refactoring.
	 * 
	 * @param offset
	 *            the offset of the selection
	 * @param length
	 *            the length of the selection
	 * @param startLine
	 *            the start line of the selection
	 * @param endLine
	 *            the end line of the selection
	 * @param selectedText
	 *            the selected text
	 * @param origin
	 *            the origin file
	 * @param destinations
	 *            the destination files
	 */
	public JavaRefactoringInfo(int offset, int length, int startLine,
			int endLine, String selectedText, IFile origin) {
		super(offset, length, startLine, endLine, selectedText, origin);
		this.javaCompilationUnit = JavaUtil
				.createJavaCompilationUnit(this.origin);
		this.selectedNodes = JavaUtil.getSelectedNodes(
				this.javaCompilationUnit, this.startOffset, this.length);
	}

	/**
	 * Returns the compilation unit.
	 * 
	 * @return the compilation unit
	 */
	public CompilationUnit getJavaCompilationUnit() {
		return this.javaCompilationUnit;
	}

	/**
	 * Returns the list of nodes in the selection.
	 * 
	 * @return the nodes in the selection
	 */
	public LinkedList<ASTNode> getSelectedNodes() {
		return this.selectedNodes;
	}

	/*
	 * (non-Javadoc)
	 * @see org.cesar.flip.flipex.RefactoringInfo#generateClone()
	 */
	@Override
	public JavaRefactoringInfo generateClone() {
		JavaRefactoringInfo info = new JavaRefactoringInfo(this.startOffset,
				this.length, this.startLine, this.endLine, this.selectedText,
				this.origin);
		info.setKeepSelection(true);
		return info;
	}
}
