package org.cesar.flip.flipex.extractors;

import java.util.LinkedHashSet;
import java.util.Set;

/**
 * Abstract class that is responsable for storage information
 * about a technique. 
 * All new techniques must to extend this class. 
 * 
 * @author Vilmar Nepomuceno (vsn@cesar.org.br)
 *
 */
public abstract class ExtractionTechnique implements IExtractionTechnique {
	
	/**
	 * The extractors belonging to this technique
	 */
	private Set<IExtractor> extractors;

	/**
	 * The description of this technique
	 */
	private String description;

	/**
	 * Name of the technique
	 */
	private String name;

	public ExtractionTechnique() {
		this.extractors = new LinkedHashSet<IExtractor>();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.cesar.flip.flipex.extractors.IExtractionTechnique#addExtractor(org.cesar.flip.flipex.extractors.IExtractor)
	 */
	public void addExtractor(IExtractor extractor) {
		this.extractors.add(extractor);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.cesar.flip.flipex.extractors.IExtractionTechnique#getDescription()
	 */
	public String getDescription() {
		return this.description;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.cesar.flip.flipex.extractors.IExtractionTechnique#getExtractors()
	 */
	public Set<IExtractor> getExtractors() {
		return this.extractors;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see org.cesar.flip.flipex.extractors.IExtractionTechnique#setDescription(java.lang.String)
	 */
	public void setDescription(String description) {
		this.description = description;
	}
	
	/*
	 * (non-Javadoc)
	 * @see org.cesar.flip.flipex.extractors.IExtractionTechnique#setName(java.lang.String)
	 */
	public void setName(String name) {
		this.name = name;
	}
	
	/*
	 * (non-Javadoc)
	 * @see org.cesar.flip.flipex.extractors.IExtractionTechnique#getName()
	 */
	public String getName() {
		return this.name;
	}
}
