package org.cesar.flip.flipex.extractors;

/**
 * Represents an extractor that didn't have all its validations successful.
 * 
 * @author Andra Menezes (afm2@cesar.org.br)
 * 
 */
public class FailedExtractor {

	/**
	 * The extractor that can't be used.
	 */
	private IExtractor extractor;

	/**
	 * The description of the validation problem.
	 */
	private String validationProblemDescription;

	/**
	 * The path of the resource that originated the validation problem.
	 */
	private String validationProblemPath;

	/**
	 * Creates a representation of an extractor that didn't have successful
	 * validation.
	 * 
	 * @param extractor
	 *            the extractor that can't be used
	 * @param validationProblemDescription
	 *            the description of the problem
	 * @param validationProblemPath
	 *            the path of the resource that originated the validation
	 *            problem
	 */
	public FailedExtractor(IExtractor extractor,
			String validationProblemDescription, String validationProblemPath) {
		this.extractor = extractor;
		this.validationProblemDescription = validationProblemDescription;
		this.validationProblemPath = validationProblemPath;
	}

	/**
	 * Returns the description of the validation problem.
	 * 
	 * @return the description of the validation problem
	 */
	public String getValidationProblemDescription() {
		return this.validationProblemDescription;
	}

	/**
	 * Returns the path of the resource that originated the validation problem
	 * 
	 * @return the resource's path
	 */
	public String getValidationProblemPath() {
		return this.validationProblemPath;
	}

	/**
	 * Returns the extractor that didn't have successful validation.
	 * 
	 * @return the extractor that didn't have successful validation
	 */
	public IExtractor getExtractor() {
		return this.extractor;
	}
}
