package org.cesar.flip.flipex.extractors;

import java.util.Set;

/**
 * Interface describing what operations FLIPex's techniques must provide.
 * 
 * @author Vilmar Nepomuceno (vsn@cesar.org.br)
 * 
 * @see ExtractionTechnique
 */
public interface IExtractionTechnique {
	
	/**
	 * Gets the technique description.
	 * 
	 * @return
	 *       The description of the technique
	 */
	public String getDescription();

	/**
	 * Adds a relation between a extractor and the technique.
	 * 
	 * @param extractor
	 * 				The extractor to be related.
	 */
	public void addExtractor(IExtractor extractor);

	/**
	 * Gets the extractors related with this technique.
	 * 
	 * @return
	 *       The extractors
	 */
	public Set<IExtractor> getExtractors();

	/**
	 * Sets the technique description.
	 * 
	 * @param description
	 * 				The new description of the technique.
	 */
	public void setDescription(String description);

	/**
	 * Sets the name of the technique.
	 * 
	 * @param name
	 */
	public void setName(String name);
	
	/**
	 * Gets the name of the technique.
	 * 
	 * @return 
	 * 		Name of the technique
	 */
	public String getName();
}
