package org.cesar.flip.flipex.util;

import org.eclipse.core.runtime.Assert;
import org.eclipse.jdt.core.dom.ASTNode;
import org.eclipse.jdt.core.dom.BodyDeclaration;
import org.eclipse.jdt.core.dom.Javadoc;
import org.eclipse.jdt.core.dom.Modifier;
import org.eclipse.jdt.internal.corext.dom.Selection;
import org.eclipse.jface.text.IRegion;

@SuppressWarnings("restriction")
public class FlipSelection extends Selection {

	private Selection selection;

	protected FlipSelection(int s, int l) {
		Assert.isTrue((s >= 0) && (l >= 0));
		this.selection = Selection.createFromStartLength(s, l);
	}

	@Override
	public int getOffset() {
		return this.selection.getOffset();
	}

	@Override
	public int getLength() {
		return this.selection.getLength();
	}

	@Override
	public int getInclusiveEnd() {
		return this.selection.getInclusiveEnd();
	}

	@Override
	public int getExclusiveEnd() {
		return this.selection.getExclusiveEnd();
	}

	@Override
	public int getVisitSelectionMode(ASTNode node) {
		return this.selection.getVisitSelectionMode(node);
	}

	@Override
	public int getEndVisitSelectionMode(ASTNode node) {
		return this.selection.getEndVisitSelectionMode(node);
	}

	// cover* methods do a closed interval check.

	@Override
	public boolean covers(int position) {
		return this.selection.covers(position);
	}

	@Override
	public boolean covers(ASTNode node) {
		int nodeStart = node.getStartPosition();
		int nodeModifierStart = nodeStart;

		if (node instanceof BodyDeclaration) {
			Javadoc javadoc = ((BodyDeclaration) node).getJavadoc();
			if (javadoc != null) {
				Modifier modifier = (Modifier) ((BodyDeclaration) node)
						.modifiers().get(0);
				nodeModifierStart = modifier.getStartPosition();
			}
		}

		return (this.getOffset() <= nodeModifierStart)
				&& (nodeStart + node.getLength() <= this.getExclusiveEnd());
	}

	@Override
	public boolean coveredBy(ASTNode node) {
		return this.selection.coveredBy(node);
	}

	@Override
	public boolean coveredBy(IRegion region) {
		return this.selection.coveredBy(region);
	}

	@Override
	public boolean endsIn(ASTNode node) {
		return this.selection.endsIn(node);
	}

	@Override
	public boolean liesOutside(ASTNode node) {
		return this.selection.liesOutside(node);
	}

	@Override
	public String toString() {
		return this.selection.toString();
	}
}
