package org.cesar.flip.flipex.util;

import java.util.LinkedList;

import org.eclipse.core.resources.IFile;
import org.eclipse.jdt.core.ICompilationUnit;
import org.eclipse.jdt.core.JavaCore;
import org.eclipse.jdt.core.dom.AST;
import org.eclipse.jdt.core.dom.ASTNode;
import org.eclipse.jdt.core.dom.ASTParser;
import org.eclipse.jdt.core.dom.CompilationUnit;
import org.eclipse.jdt.internal.corext.dom.SelectionAnalyzer;

/**
 * Utility class for Java AST creation and information retrieval.
 * 
 * @author Fernando Calheiros (fernando.calheiros@cesar.org.br)
 * 
 */
@SuppressWarnings("restriction")
public class JavaUtil {
	/**
	 * Creates an AST from the java source code in the given file, with resolved
	 * bindings.
	 * 
	 * @param source
	 *            Java source code file
	 * @return The AST generated from the provided java source code
	 */
	public static CompilationUnit createJavaCompilationUnit(IFile source) {
		ICompilationUnit sourceICompilationUnit = JavaCore
				.createCompilationUnitFrom(source);

		ASTParser parser = ASTParser.newParser(AST.JLS3);

		parser.setSource(sourceICompilationUnit);

		parser.setCompilerOptions(JavaCore.getDefaultOptions());

		parser.setResolveBindings(true);

		CompilationUnit sourceAST = (CompilationUnit) parser.createAST(null);

		sourceAST.recordModifications();

		return sourceAST;
	}

	/**
	 * Lists all selected nodes within the provided selection.
	 * 
	 * @param javaCompilationUnit
	 *            <code>CompilationUnit</code> of the Java code where the code
	 *            is selected
	 * @param offset
	 *            Initial selection position
	 * @param length
	 *            Selection length
	 * @return Every AST node within the selected java code
	 */
	public static LinkedList<ASTNode> getSelectedNodes(
			CompilationUnit javaCompilationUnit, int offset, int length) {
		FlipSelection selection = new FlipSelection(offset, length);
		SelectionAnalyzer selectionAnalyzer = new SelectionAnalyzer(selection,
				false);

		javaCompilationUnit.accept(selectionAnalyzer);

		ASTNode nodes[] = selectionAnalyzer.getSelectedNodes();

		LinkedList<ASTNode> nodesList = new LinkedList<ASTNode>();

		for (ASTNode node : nodes) {
			nodesList.add(node);
		}

		return nodesList;
	}
}
