package org.cesar.flip.flipex.validators;

import org.eclipse.core.resources.IFile;

/**
 * A description of the problems encountered by a validator.
 * 
 * @author Fernando Calheiros (fernando.calheiros@cesar.org.br)
 * 
 */
public class ValidationProblem {

	/**
	 * The problem's description.
	 */
	private String description;

	/**
	 * The file that originated this problem.
	 */
	private IFile resource;

	/**
	 * Creates a validation problem that happened while analyzing the provided
	 * file.
	 * 
	 * @param description
	 *            The description of problem
	 * @param resource
	 *            The file of problem
	 */
	public ValidationProblem(String description, IFile resource) {
		this.description = description;
		this.resource = resource;
	}

	/**
	 * The description of the problem.
	 * 
	 * @return <code>String</code> with the problem's description.
	 */
	public String getDescription() {
		return this.description;
	}

	/**
	 * The file that generated the validation problem.
	 * 
	 * @return <code>IFile</code>
	 */
	public IFile getResource() {
		return this.resource;
	}

	/**
	 * The path of the problem's resource.
	 * 
	 * @return <code>String</code> with the path of the problem's resource.
	 */
	public String getResourcePath() {
		String path = "";
		if (this.resource != null) {
			path = this.resource.getFullPath().toPortableString();
		}
		return path;
	}

}
