package org.cesar.flip.flipex.validators;

import java.util.LinkedList;
import java.util.List;

/**
 * Contains the list of validation problems that were reported during the
 * execution of a validator.
 * 
 * @author Davi Pires (davi.pires@cesar.org.br)
 * 
 */
public class ValidatorStatus {

	/**
	 * Problems that occured during the execution of the validator.
	 */
	private List<ValidationProblem> problems;

	/**
	 * The validator which reported the problems.
	 */
	private IValidator parent;

	/**
	 * Creates a status object that will be used for storing the provided
	 * validator's problems.
	 * 
	 * @param validator
	 *            The validator which may report problems
	 */
	public ValidatorStatus(IValidator validator) {
		this.parent = validator;
		this.problems = new LinkedList<ValidationProblem>();
	}

	/**
	 * Adds a problem generated by the validator.
	 * 
	 * @param problem
	 *            The problem that was reported
	 */
	public void addProblem(ValidationProblem problem) {
		this.problems.add(problem);
	}

	/**
	 * Returns the validator this status represents.
	 * 
	 * @return The validator this status represents
	 */
	public IValidator getParent() {
		return this.parent;
	}

	/**
	 * Returns the list of problems reported by the validator this status
	 * represents.
	 * 
	 * @return The list of problems
	 */
	public List<ValidationProblem> getProblems() {
		return this.problems;
	}

	/**
	 * Tell wheter the validator reported any problems.
	 * 
	 * @return <code>true</code> if tha validator didn't report any problems
	 */
	public boolean isSuccessful() {
		return this.problems.isEmpty();
	}
}
