package org.cesar.flip.flipg.model;

/**
 * Interface to specify component's behavior.
 * 
 * @author Andrea Menezes  andrea.menezes@cesar.org.br
 * @author Fernando Calheiros  fernando.calheiros@cesar.org.br
 * @author Geraldo Fernandes  geraldo.fernandes@cesar.org.br
 * @author Vilmar Nepomuceno  vilmar.nepomuceno@cesar.org.br
 */
public interface IComponent {
	public String getType();

	/**
	 * Returns the name of the component.
	 * 
	 * @return the name of the component.
	 */
	public String getName();

	/**
	 * Sets the name of the component.
	 * 
	 * @param name
	 *            the new name of the component.
	 */
	public void setName(String name);

	/**
	 * Check if the component is new.
	 * 
	 * @return <b><code>true</code></b> if the component is new.
	 */
	public boolean isNewComponent();

	/**
	 * Returns the expression of the component.
	 * 
	 * @return The expression of the component.
	 */
	public IExpression getExpression();

	/**
	 * Add an expression to the component.
	 * 
	 * @param newExpression
	 *            The new expression to be added in component.
	 */
	public void addExpression(IExpression newExpression);

	/**
	 * Returns the absolute path of variation solver.
	 * 
	 * @return The absolute path of variation solver.
	 */
	public String getPath();

	/**
	 * Returns the text that represents the variation solver for storing in the
	 * configuration knowledge.
	 * 
	 * @return the text that represents the variation solver for storing in the
	 *         configuration knowledge
	 */
	public String getStorageText();
	
	/**
	 * 
	 * @param path
	 */
	public void updatePath(String path);

}
