package org.cesar.flip.flipg.model;

import java.util.List;

import org.cesar.flip.flipex.PreprocessingRefactoringInfo;
import org.cesar.flip.flipex.RefactoringInfo;
import org.cesar.flip.flipex.extractors.IExtractor;

public class TagExtractorsAssociation {
	
	/**
	 * Tag to be associated.
	 */
	RefactoringInfo info;
	
	/**
	 * Extractors to be associated.
	 */
	List<IExtractor> extractors;
	
	/**
	 * Selected Extractor.
	 */
	IExtractor selectedExtractor;

	/**
	 * Constructs an association between a tag  and a
	 * list of extractors.
	 * 
	 * @param tag
	 *            tag to be associated.
	 * @param extractors
	 *            list of extractors to be associated.
	 */
	public TagExtractorsAssociation(RefactoringInfo info, List<IExtractor> extractors) {
		this.info = info;
		this.extractors = extractors;
	}



	public RefactoringInfo getInfo() {
		return info;
	}



	public void setInfo(RefactoringInfo info) {
		this.info = info;
	}



	/**
	 * Returns the list of extractors associated.
	 * 
	 * @return The list of extractors associated.
	 */
	public List<IExtractor> getExtractors() {
		return extractors;
	}

	/**
	 * Sets the list of extractors associated.
	 * 
	 * @param extractors
	 *            The list of extractors associated.
	 */
	public void setExtractors(List<IExtractor> extractors) {
		this.extractors = extractors;
	}

	/**
	 * Returns the selected extractors.
	 * 
	 * @return The selected extractor.
	 */
	public IExtractor getSelectedExtractor() {
		return selectedExtractor;
	}

	/**
	 * Sets the selected extractor.
	 * 
	 * @param extractor
	 *            The selected extractor.
	 */
	public void setSelectedExtractor(Integer position) {
		this.selectedExtractor = this.extractors.get(position);
	}

	public Integer getSelectedExtractorPosition() {
		int position = 0;
		if(this.selectedExtractor != null) {
			position = this.extractors.indexOf(this.selectedExtractor);
		}
		this.selectedExtractor = this.extractors.get(0);
		return position;
	}	
	
	public String getTag(){
		return ((PreprocessingRefactoringInfo)this.info).getTag();
	}

}
