package org.cesar.flip.flipg.model.expressions;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;
import java.util.Set;
import java.util.TreeSet;

import org.cesar.flip.Facade;
import org.cesar.flip.flipg.model.IExpression;
import org.cesar.flip.flipg.model.IFeature;
import org.cesar.flip.flipg.model.IFeature.FeatureType;
import org.eclipse.core.runtime.CoreException;

public class CloneGenerator {
	private Set<IExpression> clones;

	private List<String> currentSolution;

	public IExpression expression;

	private String formatString;

	boolean canCloneMore = false;

	public CloneGenerator(IExpression expression) {
		this.expression = expression;
		this.clones = new TreeSet<IExpression>(new Comparator<IExpression>() {
			public int compare(IExpression e1, IExpression e2) {
				return e1.getCode().compareTo(e2.getCode());
			}
		});
		this.currentSolution = new ArrayList<String>();
	}

	public Set<IExpression> generateClones() {
		CloneVisitor visitor = new CloneVisitor();
		this.expression.accept(visitor);

		this.formatString = visitor.getFormatString();
		List<IFeature> cloneables = visitor.getCloneableFeaturesList();

		this.queens(cloneables, 0);

		return this.clones;
	}

	public void queens(List<IFeature> cloneables, int position) {
		if (position != cloneables.size()) {
			IFeature currentFeature = cloneables.get(position);
			List<IFeature> alternatives = this.getAlternatives(currentFeature);
			for (IFeature feature : alternatives) {
				this.currentSolution.add(feature.getName());
				this.queens(cloneables, position + 1);
				this.currentSolution.remove(position);
			}
		} else {
			StringWriter stringWriter = new StringWriter();
			PrintWriter writer = new PrintWriter(stringWriter);
			writer.printf(this.formatString, this.currentSolution.toArray());
			try {
				this.clones.add(Facade.getInstance().parseExpression(
						stringWriter.toString()));
			} catch (CoreException e) {
				e.printStackTrace();
			}
		}
	}

	private List<IFeature> getAlternatives(IFeature feature) {
		List<IFeature> alternatives = new ArrayList<IFeature>();
		for (IFeature sibling : feature.getParent().getChildren()) {
			if (sibling.getType().equals(FeatureType.ALTERNATIVE)) {
				alternatives.add(sibling);
			}
		}
		return alternatives;
	}

	class CloneVisitor extends ExpressionVisitor {
		StringBuilder builder = new StringBuilder();

		List<IFeature> cloneable = new ArrayList<IFeature>();

		public String getFormatString() {
			return this.builder.toString();
		}

		public List<IFeature> getCloneableFeaturesList() {
			return this.cloneable;
		}

		@Override
		public void visitAndExpression(AndExpression andExpression) {
			this.builder.append("(");
			andExpression.getLhs().accept(this);
			this.builder.append(" and ");
			andExpression.getRhs().accept(this);
			this.builder.append(")");
		}

		@Override
		public void visitIFeature(IFeature feature) {
			if (feature.getType().equals(FeatureType.ALTERNATIVE)) {
				this.builder.append("%s");
				this.cloneable.add(feature);
			} else {
				this.builder.append(feature.getName());
			}
		}

		@Override
		public void visitNotExpression(NotExpression notExpression) {
			this.builder.append("not(");
			notExpression.getExp().accept(this);
			this.builder.append("");
		}

		@Override
		public void visitOrExpression(OrExpression orExpression) {
			this.builder.append("(");
			orExpression.getLhs().accept(this);
			this.builder.append(" or ");
			orExpression.getRhs().accept(this);
			this.builder.append(")");
		}
	}
}
